@@ -1,9 +1,9 @@
 #
-# $Id: Encode.pm,v 1.74 2002/05/28 18:33:54 dankogai Exp dankogai $
+# $Id: Encode.pm,v 1.76 2002/08/25 15:09:51 dankogai Exp dankogai $
 #
 package Encode;
 use strict;
-our $VERSION = do { my @r = (q$Revision: 1.74 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 1.76 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 our $DEBUG = 0;
 use XSLoader ();
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -552,7 +552,7 @@ buffer. Here is some sample code that does exactly this:
   while(defined(read $fh, $buffer, 256)){
     # buffer may end in a partial character so we append
     $data .= $buffer;
-    $utf8 .= decode($encoding, $data, ENCODE::FB_QUIET);
+    $utf8 .= decode($encoding, $data, Encode::FB_QUIET);
     # $data now contains the unprocessed partial character
   }
 
